import './NewGame.css';
import React from 'react';
import { AppData } from '../../context/data'
import { AppContext } from '../../context/app'
import { useLocation, matchPath } from "react-router";
import { SelectPlayer } from '../Player';
import { WhiteStone, BlackStone } from './Stone';


export default function NewGame() {
  const [ctx, dispatchCtx] = React.useContext(AppContext)
  const [data] = React.useContext(AppData)
  const { pathname } = useLocation();
  const isMyPath = matchPath("/game/new", pathname);

  if (!isMyPath)
    return

  /*
   * Name options
   */
  const nameOptions = data.leaderboard ? Object.keys(data.leaderboard).map(playerName =>
      <option key={playerName} value={playerName}>
        {data.isCurrentUser(playerName) ? 'You' : playerName}
      </option>)
    : [<option key='loading' value='…'>…loading</option>]

  const whiteOptions = Array(nameOptions)
  whiteOptions.push(<option key='default' value=''>{'white player …'}</option>)

  const blackOptions = Array(nameOptions)
  blackOptions.push(<option key='default' value=''>{'black player …'}</option>)

  /*
   * Radiobutton
   */
  const radioButton = (whitePlayer, blackPlayer) => {
    if (whitePlayer !== '' && whitePlayer === ctx.newGame.blackPlayer) {
      blackPlayer = ''
    }
    if (blackPlayer !== '' && blackPlayer === ctx.newGame.whitePlayer) {
      whitePlayer = ''
    }

    dispatchCtx({ update: "newGame", whitePlayer, blackPlayer })
  }

  const setWhitePlayer = (name) => {
    radioButton(name, ctx.newGame.blackPlayer)
  }

  const setBlackPlayer = (name) => {
    radioButton(ctx.newGame.whitePlayer, name)
  }

  /*
   * Component
   */
  return (
    <div className='new-game'>
      <div>
        <WhiteStone />
        <SelectPlayer name={ctx.newGame.whitePlayer} setName={setWhitePlayer} nameOptions={whiteOptions} />
      </div>
      <div>- vs -</div>
      <div>
        <SelectPlayer name={ctx.newGame.blackPlayer} setName={setBlackPlayer} nameOptions={blackOptions} />
        <BlackStone />
      </div>
    </div>
  )
}
