import { useState, useCallback, useEffect, } from "react"

/*
  - uri: string
  - mode:
    - null  - default, fetch data ONCE
    - interval_sec
    - interval_stop
*/

export default function usePolling(uri, onResponce, mode = null) {
    const [initialPoll, setInitialPoll] = useState(true);
    const [isPolling, setPolling] = useState(false);
    const [intervalTimer, setIntervalTimer] = useState(null);

    const pollData = useCallback(() => {
        setPolling(true);
        setInitialPoll(false);

        fetch(uri)
            .then((responce) => {
                setPolling(false);

                if (typeof mode?.interval_sec === 'number') {
                    console.log("Schedule", uri, "fetch in", mode.interval_sec, "sec");
                    const intervalTimer = setTimeout(pollData, mode.interval_sec * 1000);
                    setIntervalTimer(intervalTimer);
                }

                return responce.json();
            })
            .then((json) => {
                onResponce(json);
            })
            .catch((err) => {
                console.warn(err.message);
            })
    }, [uri, mode, onResponce]);

    useEffect(() => {
        if ((initialPoll || (typeof mode?.interval_sec === 'number' && intervalTimer === null)) && !isPolling) {
            pollData();
        }
    }, [initialPoll, mode, intervalTimer, isPolling, pollData]);

    if (mode?.interval_stop && intervalTimer) {
        console.log("Cancel scheduled fetch for", uri);
        clearTimeout(intervalTimer);
        setIntervalTimer(null);
        setInitialPoll(true);
    }


    return isPolling;
}